@@ -22,8 +22,7 @@ CREATE TABLE weblog (
   comments int(11) NOT NULL default '0',
   reads int(100) NOT NULL default '0',
   description text NOT NULL,
-  nohtml tinyint(1) NOT NULL default '0',
-  nosmiley tinyint(1) NOT NULL default '0',
+  dohtml tinyint(1) NOT NULL default '0',
   PRIMARY KEY  (blog_id),
   KEY user_id (user_id,created,title,private)
 ) TYPE=MyISAM;
@@ -43,10 +42,17 @@ CREATE TABLE weblog_category (
   PRIMARY KEY  (cat_id),
   KEY cat_pid (cat_pid)
 ) TYPE=MyISAM;
-# --------------------------------------------------------
 
 INSERT INTO weblog_category (
   cat_id, cat_pid, cat_title, cat_description, cat_created, cat_imgurl)
   VALUES (
     '1', '0', 'Miscellaneous', '', '1051983686', ''
-  );
+);
+# --------------------------------------------------------
+
+CREATE TABLE xoops_weblog_priv (
+  priv_id smallint(5) unsigned NOT NULL auto_increment,
+  priv_gid smallint(5) unsigned NOT NULL default '0',
+  PRIMARY KEY  (priv_id)
+) TYPE=MyISAM;
+
